# coding: utf-8
import datetime

from sqlalchemy import (
    MetaData, String, Table, Column, Integer, DateTime)

from tionix_vdi_server.core.helpers import get_admin_neutron_client


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tenant_security_groups = Table(
        'tenant_security_groups', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True),
        Column('tnx_tenant_id', String(64)),
        Column('security_group_id', String(36)),
        mysql_charset='utf8'
    )
    tenant_security_groups.create()

    try:
        neutron_client = get_admin_neutron_client()
        security_groups = neutron_client.list_security_groups(
            fields=['id', 'name', 'tenant_id']
        )
    except Exception:
        pass
    else:
        security_groups_dict = {
            group['tenant_id']: group['id']
            for group in security_groups.get('security_groups', [])
            if group['name'] == 'default'
        }
        tenant_table = Table('tenants', meta, autoload=True)
        for row in tenant_table.select().with_only_columns(
                [tenant_table.c.id,
                 tenant_table.c.tenant_id]).execute().fetchall():
            row_id, tenant_id = row
            security_group_id = security_groups_dict.get(tenant_id)
            if security_group_id:
                # pylint: disable=no-value-for-parameter
                tenant_security_groups.insert().execute({
                    'created_at': datetime.datetime.utcnow(),
                    'tnx_tenant_id': row_id,
                    'security_group_id': security_group_id
                })


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tnx_tenant_security_groups = Table('tenant_security_groups',
                                       meta,
                                       autoload=True)
    tnx_tenant_security_groups.drop()
